@@ -4,10 +4,12 @@ from tensorflow import keras
 
 
 from . import modeling
+from .params import BaseParams
 
 
 class TopLayer():
-    def __init__(self, params):
+    # pylint: disable=attribute-defined-outside-init,no-member
+    def __init__(self, params: BaseParams):
         self.params = params
 
     def get_train(self):
